#######################
PyDMPushButton
#######################

.. autoclass:: pydm.widgets.pushbutton.PyDMPushButton
   :members:
   :show-inheritance:


.. note::
   See `QPushButton Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QPushButton.html>`_ for all inherited properties and methods.